@@ -42,8 +42,8 @@ def parse_args():
   worker.add_argument('-l', '--lang', dest='lang', type=str, default="python",  help='worker language (default: python)')
   worker.add_argument('-m', '--modules', dest='modules', action="append", type=str, default=[], help='additional python module paths')
   worker.add_argument('-b', '--heartbeat', dest='heartbeat', type=int, default=1,  help='worker heart beat in seconds (default: 1)')
-  worker.add_argument('-b', '--logger', dest='logger', type=str, default=None,  help='logger callback function (default: None)')
-  worker.add_argument('-v', '--verbosity', dest='verbosity', type=str, default="error",  help='logger verbosity, options are [error, completed, progress] (default: error)')
+  worker.add_argument('--logger', dest='logger', type=str, default=None,  help='logger callback function (default: None)')
+  worker.add_argument('--verbosity', dest='verbosity', type=str, default="error",  help='logger verbosity, options are [error, completed, progress] (default: error)')
 
   queue = subparsers.add_parser('queue', description='Schedule a job into the job queue')
   queue.add_argument('function_name', metavar='function_name', type=str, help='the full name of the entry point function')
@@ -94,12 +94,6 @@ def run_worker(args):
   if not args.lang is None:
     kwargs["lang"] = args.lang
 
-  if not args.logger is None:
-    kwargs['logger'] = args.logger
-
-  if not args.verbosity is None:
-    kwargs['verbosity'] = args.verbosity
-
   if (channels is None) or len(channels) == 0:
     queue = Queue(client, **kwargs)
     queues += (queue,)
@@ -114,7 +108,7 @@ def run_worker(args):
     for module in args.modules:
       sys.path.append(os.path.abspath(module))
 
-    worker = Worker(queues, heart_beat=args.heartbeat)
+    worker = Worker(queues, heart_beat=args.heartbeat, logger=args.logger, verbosity=args.verbosity)
     if (channels is None) or len(channels) == 0:
       print(f"**Started worker with heart beat of {args.heartbeat} second(s)", flush=True)
     else:
